sample.jpg - https://unsplash.com/photos/8OyKWQgBsKQ
sample.png - https://unsplash.com/photos/iar-afB0QQw

microsoft-sample.docx - produced by Microsoft Office
sample-libre-office.odt - produced by LibreOffice Writer 7.5.12
